@@ -281,6 +281,14 @@ handle_port_child_event(struct gensio_accepter *accepter, void *user_data,
     case GENSIO_ACC_EVENT_NEW_CONNECTION:
 	return port_new_con(port, data);
 
+#ifdef GENSIO_ACC_EVENT_PARMLOG
+    case GENSIO_ACC_EVENT_PARMLOG: {
+	struct gensio_parmlog_data *d = (struct gensio_parmlog_data *) data;
+	vsyslog(LOG_ERR, d->log, d->args);
+	return 0;
+    }
+#endif
+
     default:
 	return handle_acc_auth_event(port->authdir, port->pamauth,
 	    port->allowed_users, event, data);
